@@ -4,23 +4,25 @@
 #' Input for the function is either a matrix of vertex coordinates defining a 3D surface object
 #' or a mesh3d object as obtained from \code{\link{read.ply}}. 
 #'
-#' Function for digitizing "n" three-dimensional landmarks. The landmarks are "fixed" (traditional landmarks). They can be later
-#'  designated as "curve sliders" (semilandmarks, that will "slide" along curves lacking known landmarks 
-#'  if required. A sliding semi-landmark ("sliders") will slide between two designated points, along a line tangent to the specified curvature,
-#'  and must be defined as "sliders" using function \code{\link{define.sliders}} or with similar format matrix made outside R. 
+#' Function for digitizing fixed three-dimensional landmarks. The user can later designate some 
+#' as curve sliding semilandmarks, using the function \code{\link{define.sliders}} or through
+#' a semilandmark definition matrix. 
 #' 
-#' For 3D "surface sliders" (surface semilandmarks that slide over a surface) the function \code{\link{digitsurface}} should be used instead.
-#'  NOTE: Function centers the mesh before digitizing by default (center=TRUE). If one chooses not to center,
+#' To digitize 3D surface sliding semilandmarks the function \code{\link{digitsurface}} should be used instead.
+#' 
+#' For more details on the full procedure one needs to follow to digitize fixed 3D landmarks and surface
+#' sliding semilandmarks, see also the relevant vignette by running \code{vignette("geomorph.digitize3D")}.
+#' 
+#'  NOTE: The function centers the mesh before digitizing by default (center=TRUE). If one chooses not to center,
 #'  specimen may be difficult to manipulate in rgl window.
 #' 
 #' \subsection{Digitizing}{ 
-#' Digitizing is interactive between landmark selection using a mouse (see below for instructions), 
-#' and the R console. Once a point is selected, the user is asked if the system should keep or discard the 
-#' selection #'(y/n). If "y", the user is asked to continue to select the next landmark. If "n" the removes the last chosen
+#' Digitizing is interactive. Once a point is selected, the user is asked if the system should keep or discard the 
+#' selection (y/n). If "y", the user is asked to continue to select the next landmark. If "n" the removes the last chosen
 #' landmark, and the user is asked to select it again. This can be repeated until the user is comfortable with the landmark
 #' chosen. 
 #' 
-#' To digitize with a standard 3-button (PC):
+#' To digitize with a standard 3-button mouse (PC):
 #' \enumerate{
 #'  \item the RIGHT mouse button (primary) to select points to be digitized,
 #'  \item the LEFT mouse button (secondary) is used to rotate mesh, 
@@ -39,11 +41,13 @@
 #' }
 #'
 #' @param spec An object of class shape3d/mesh3d, or matrix of 3D vertex coordinates
-#' @param fixed Numeric The number landmarks (fixed, and curve sliders if desired)
-#' @param index Logical Whether selected landmark addresses should be returned (internal use only)
-#' @param ptsize Numeric Size to plot the mesh points (vertices), e.g. 0.1 for dense meshes, 3 for sparse meshes 
-#' @param center Logical Whether the object 'spec' should be centered prior to digitizing (default {center=TRUE})
-#' @return Function writes to the working directory an NTS file with the name of the specimen and .nts suffix containing the landmark coordinates.
+#' @param fixed The number of landmarks to be digitized (fixed, and curve sliders if desired)
+#' @param index Whether selected landmark addresses should be returned (internal use only)
+#' @param ptsize Size of mesh points (vertices), e.g. 0.1 for dense meshes, 3 for sparse meshes 
+#' @param center Should the object 'spec' be centered prior to digitizing?
+#' 
+#' @return Function returns (if assigned to an object) and writes to the working directory an NTS
+#'  file, containing the landmark coordinates. The file name corresponds to the name of the specimen.
 #' If index=FALSE function returns to the console an n x 3 matrix containing the x,y,z coordinates of the digitized landmarks.  
 #' If index=TRUE, function returns a list:
 #'  \item{selected}{a matrix containing the x,y,z coordinates of the digitized landmarks} 
@@ -71,7 +75,7 @@ digit.fixed <- function(spec, fixed, index=FALSE, ptsize = 1, center = TRUE)
     if (center == FALSE){ specimen <- spec }
   } else { stop ("File is not matrix in form: vertices by xyz")} 
   clear3d(); ids <- plot3d(specimen[,1],specimen[,2],specimen[,3],size=ptsize,aspect=FALSE)
-  if (!is.null(mesh)) { shade3d(mesh, add=TRUE) }
+  if (!is.null(mesh)) { shade3d(mesh, meshColor="legacy", add=TRUE) }
   selected<-matrix(NA,nrow=fixed,ncol=3);fix<-NULL    
   for (i in 1:fixed)      {
     keep<-ans<-NULL
@@ -93,7 +97,7 @@ digit.fixed <- function(spec, fixed, index=FALSE, ptsize = 1, center = TRUE)
       fix<-fix[-i] 
       rgl.bringtotop(stay = FALSE)
       clear3d();ids <- plot3d(specimen[,1],specimen[,2],specimen[,3],size=ptsize,aspect=FALSE)
-      if (!is.null(mesh)) { shade3d(mesh, add=TRUE) }
+      if (!is.null(mesh)) { shade3d(mesh, meshColor="legacy",add=TRUE) }
       if(sum(1-is.na(selected))>0){
         points3d(selected[,1],selected[,2],selected[,3],size=10,color="red",add=TRUE)
       }      
