@@ -4,22 +4,23 @@
 #' Input for the function is either a matrix of vertex coordinates defining a 3D surface object
 #' or a mesh3d object as obtained from \code{\link{read.ply}}. 
 #' 
-#' Function for digitizing fixed 3D landmarks and placing "surface sliders", semilandmarks that slide over a surface.
-#'  Following selection of fixed points (see digitizing below), function finds surface semilandmarks following 
+#' Function for digitizing fixed 3D landmarks and placing surface sliding semilandmarks using a previously created template.
+#'  Following the selection of fixed points (see digitizing below), the function finds surface semilandmarks following the 
 #'  algorithm outlined in Gunz et al. (2005) and Mitteroecker and Gunz (2009). digitsurface finds the same number of surface 
-#'  semilandmarks as the template (created by \code{\link{buildtemplate}}) by downsampling scanned mesh, registering template with 
-#'  current specimen via GPA. A nearest neighbor algorithm is used to match template surface landmarks to current specimen's. 
+#'  semilandmarks as the template (created by \code{\link{buildtemplate}}) by downsampling the scanned mesh, after registering the template with 
+#'  the current specimen via GPA. A nearest neighbor algorithm is used to match template surface semilandmarks to mesh points of the current specimen. 
 #'  To use function digitsurface, the template must be constructed first, and 'template.txt' be in the working directory. Because template 
 #'  matching is based on the correspondence of fixed landmark points in the template and the specimen, a minimum of four fixed landmarks must be used. 
 #' 
-#' Some of the "fixed" landmarks digitized with digitsurface can be later designated as "curve sliders" using function 
-#' \code{\link{define.sliders}} if required (see details in \code{\link{digit.fixed}}).
+#' 
+#' #' For more details on the full procedure one needs to follow to digitize fixed 3D landmarks and surface
+#' sliding semilandmarks, see also the relevant vignette by running \code{vignette("geomorph.digitize3D")}.
+#'  
 #'  NOTE: Function centers the mesh before digitizing by default (center=TRUE). If one chooses not to center,
 #'  specimen may be difficult to manipulate in rgl window.
 #' 
 #' \subsection{Digitizing}{
-#' Digitizing is interactive between landmark selection using a mouse (see below for instructions), 
-#' and the R console. Once a point is selected, the user is asked if the system should keep or discard the 
+#' Digitizing of fixed landmarks is interactive. Once a point is selected, the user is asked if the system should keep or discard the 
 #' selection (y/n). If "y", the user is asked to continue to select the next landmark. If "n" the removes the last chosen
 #' landmark, and the user is asked to select it again. This can be repeated until the user is comfortable with the landmark
 #' chosen. 
@@ -49,14 +50,15 @@
 #' landmarks and fit the template of sliding semilandmarks.
 #' }
 #'
-#' @param spec Name of surface file, as either an object of class shape3d/mesh3d, or matrix of three-dimensional vertex coordinates.
-#' @param fixed numeric Either: a single value designating the number of fixed template landmarks to be selected by \code{\link{digit.fixed}}, OR a p-x-k matrix of 3D coordinates collected previously
-#' @param ptsize numeric: Size to plot the mesh points (vertices), e.g. 0.1 for dense meshes, 3 for sparse meshes
-#' @param center Logical Whether the object 'spec' should be centered prior to digitizing (default {center=TRUE})
+#' @param spec An object of class shape3d/mesh3d, or matrix of 3D vertex coordinates
+#' @param fixed Either a numeric value designating the number of fixed landmarks to be selected by \code{\link{digit.fixed}}, or a matrix of 3D coordinates collected previously
+#' @param ptsize Size of mesh points (vertices), e.g. 0.1 for dense meshes, 3 for sparse meshes
+#' @param center Should the object 'spec' be centered prior to digitizing?
 #' @seealso \code{\link{buildtemplate}}
 #' @seealso \code{\link{read.ply}} 
 #' @seealso \code{\link{digit.fixed}} 
-#' @return Function writes to the working directory an NTS file with the name of the specimen and .nts suffix containing the landmark coordinates.   
+#' @return Function returns (if assigned to an object) and writes to the working directory an NTS
+#'  file, containing the landmark coordinates. The file name corresponds to the name of the specimen.   
 #' @references Gunz P, Mitteroecker P, & Bookstein FJ (2005) Semilandmarks in Three Dimensions. Modern Morphometrics in Physical Anthropology, ed Slice DE (Springer-Verlag, New York), pp 73-98.
 #' @references Mitteroecker P & Gunz P (2009) Advances in Geometric Morphometrics. Evolutionary Biology 36(2):235-247. 
 #' @export
@@ -109,7 +111,7 @@ digitsurface<-function(spec, fixed, ptsize = 1, center = TRUE)    {
   clear3d();plot3d(specimen[,1],specimen[,2],specimen[,3],size=ptsize,aspect=FALSE)
   if (!is.null(mesh)) { 
     mesh$vb <- rbind(t(specimen), 1)
-    shade3d(mesh, add=TRUE) 
+    shade3d(mesh, meshColor="legacy", add=TRUE) 
   }
   points3d(specimen[lmk.add,],col="red",size=10)
   points3d(template.tps,col="blue",size=10)
